import { ArnFormat, IResolvable, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnIPAMScope } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { IIpam } from '.';
import { IIpamPool } from './ipam-pool';
import { IIpamScope, IpamScopeAttributes } from './ipam-scope';
export interface IPrivateIpamScope extends IIpamScope {
    addPool(): IIpamPool;
}
/**
 * Optional configuration for the IPAM scope resource.
 */
export interface PrivateIpamScopeOptions {
    /**
     * The description of the scope.
     *
     * @see [IPAMScope Description](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-description)
     */
    readonly description?: string;
}
/**
 * Configuration for the IPAM scope resource.
 */
export interface PrivateIpamScopeProps extends ResourceProps, PrivateIpamScopeOptions {
    /**
     * The IPAM for which you're creating this scope.
     *
     * @see [IPAMScope IpamId](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-ipamid)
     */
    readonly ipam: IIpam;
}
declare abstract class PrivateIpamScopeBase extends Resource implements IPrivateIpamScope {
    /**
     * The ARN of the scope.
     */
    abstract readonly ipamScopeArn: string;
    /**
      * The ID of an IPAM scope.
      */
    abstract readonly ipamScopeId: string;
    /**
      * The ARN of an IPAM.
      */
    abstract readonly ipamScopeIpamArn: string;
    /**
      * Defines if the scope is the default scope or not.
      */
    abstract readonly ipamScopeIsDefault: IResolvable;
    /**
      * The number of pools in a scope.
      */
    abstract readonly ipamScopePoolCount: number;
    /**
      * The type of the scope.
      */
    abstract readonly ipamScopeType: string;
    addPool(): IIpamPool;
}
export declare class PrivateIpamScope extends PrivateIpamScopeBase {
    /**
     * The format for Amazon Resource Names (ARN's) for IPAM scope resources.
     */
    static readonly ARN_FORMAT: ArnFormat;
    /**
     * Imports an existing IPAM scope by specifying its Amazon Resource Name
     * (ARN).
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamScopeArn The ARN of the existing IPAM scope to be imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeArn(scope: IConstruct, id: string, ipamScopeArn: string): IPrivateIpamScope;
    /**
     * Imports an existing IAPM scope by explicitly specifying its attributes.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param attrs The attributes of the existing IPAM scope to be imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeAttributes(scope: IConstruct, id: string, attrs: IpamScopeAttributes): IPrivateIpamScope;
    /**
     * Imports an existing IPAM scope by explicitly specifying its AWS generated
     * ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamScopeId The AWS generated ID of the existing IPAM scope to be
     * imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeId(scope: IConstruct, id: string, ipamScopeId: string): IPrivateIpamScope;
    /**
     * The description of the scope.
     *
     * @see [IPAMScope Description](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-description)
     *
     * @group Inputs
     */
    readonly description?: string;
    /**
     * The IPAM for which you're creating this scope.
     *
     * @see [IPAMScope IpamId](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-ipamid)
     *
     * @group Inputs
     */
    readonly ipam: IIpam;
    /**
     * The underlying IPAM scope CloudFormation resource.
     *
     * @see [AWS::EC2::IPAMScope](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html)
     *
     * @group Resources
     */
    readonly resource: CfnIPAMScope;
    /**
     * The ARN of the scope.
     */
    readonly ipamScopeArn: string;
    /**
     * The ID of an IPAM scope.
     */
    readonly ipamScopeId: string;
    /**
     * The ARN of an IPAM.
     */
    readonly ipamScopeIpamArn: string;
    /**
     * Defines if the scope is the default scope or not.
     */
    readonly ipamScopeIsDefault: IResolvable;
    /**
     * The number of pools in a scope.
     */
    readonly ipamScopePoolCount: number;
    /**
     * The type of the scope.
     */
    readonly ipamScopeType: string;
    constructor(scope: IConstruct, id: string, props: PrivateIpamScopeProps);
}
export {};
